@@ -11,9 +11,10 @@
 #'
 #' @examples
 #' test_df <- tidytable(
-#'   a = c(1,2,3),
-#'   b = c(4,5,6),
-#'   c = c("a","a","b"))
+#'   a = 1:3,
+#'   b = 4:6,
+#'   c = c("a","a","b")
+#' )
 #'
 #' test_df %>%
 #'   filter.(a >= 2, b >= 4)
@@ -26,31 +27,33 @@ filter. <- function(.df, ..., .by = NULL) {
 
 #' @export
 filter..data.frame <- function(.df, ..., .by = NULL) {
-
   .df <- as_tidytable(.df)
 
   .by <- enquo(.by)
 
   dots <- enquos(...)
+  if (length(dots) == 0) return(.df)
 
-  data_env <- env(quo_get_env(dots[[1]]), .df = .df)
+  mask <- build_data_mask(dots)
+
+  dots <- prep_exprs(dots, .df)
+
+  i <- expr(Reduce('&', list(!!!dots)))
 
   if (quo_is_null(.by)) {
+    dt_expr <- call2_i(.df, i)
 
-    .df <- eval_quo(
-      .df[Reduce('&', list(!!!dots))],
-      new_data_mask(data_env), env = caller_env()
-    )
-
+    .df <- eval_tidy(dt_expr, mask, caller_env())
   } else {
     .by <- select_vec_chr(.df, !!.by)
 
     col_order <- names(.df)
 
-    .df <- eval_quo(
-      .df[, .SD[Reduce('&', list(!!!dots))], by = !!.by],
-      new_data_mask(data_env), env = caller_env()
-    )
+    j <- expr(.SD[!!i])
+
+    dt_expr <- call2_j(.df, j, .by)
+
+    .df <- eval_tidy(dt_expr, mask, caller_env())
 
     setcolorder(.df, col_order)
   }
