@@ -23,25 +23,10 @@
 #'   mutate.(new_col = ifelse.(x > 2, 2, 0))
 ifelse. <- function(conditions, true, false, na = NA) {
 
-  conditions <- conditions
-  true <- true
-  false <- false
-  na <- na
-
   ptype <- vec_ptype_common(true, false, na)
 
-  true <- vec_cast(true, ptype)
-  false <- vec_cast(false, ptype)
-  na <- vec_cast(na, ptype)
+  args <- vec_cast_common(true = true, false = false, na = na, .to = ptype)
 
-  fifelse(conditions, true, false, na = na)
-}
+  fifelse(conditions, args$true, args$false, args$na)
 
-#' @export
-#' @rdname dt_verb
-#' @inheritParams ifelse.
-dt_ifelse <- function(conditions, true, false, na = NA) {
-  deprecate_stop("0.5.2", "tidytable::dt_ifelse()", "ifelse.()")
-
-  ifelse.(conditions, true, false, na)
 }
