@@ -50,7 +50,7 @@ nest..data.frame <- function(.df, ..., .names_sep = NULL) {
   dots <- unname(dots)
 
   if (!is.null(.names_sep)) {
-    nest_cols <- eval_quo(select_vec_chr(.df, !!!dots))
+    nest_cols <- select_dots_chr(.df, !!!dots)
 
     new_names <- paste(.key, nest_cols, sep = .names_sep)
 
